{
  "type": "record",
  "Aspect": {
    "name": "dataHubExecutionRequestArtifactsLocation"
  },
  "name": "ExecutionRequestArtifactsLocation",
  "namespace": "com.linkedin.pegasus2avro.execution",
  "fields": [
    {
      "type": "string",
      "name": "location",
      "doc": "The location where artifacts are present"
    }
  ],
  "doc": "The result location of an execution request"
}