# mypy: ignore-errors
# flake8: noqa

# This file is autogenerated by /metadata-ingestion/scripts/avro_codegen.py
# Do not modify manually!

# pylint: skip-file
# fmt: off
# isort: skip_file
from ......schema_classes import NotificationContextClass
from ......schema_classes import NotificationMessageClass
from ......schema_classes import NotificationRecipientClass
from ......schema_classes import NotificationRecipientOriginTypeClass
from ......schema_classes import NotificationRecipientTypeClass
from ......schema_classes import NotificationRequestClass
from ......schema_classes import NotificationSinkClass
from ......schema_classes import NotificationSinkTypeClass


NotificationContext = NotificationContextClass
NotificationMessage = NotificationMessageClass
NotificationRecipient = NotificationRecipientClass
NotificationRecipientOriginType = NotificationRecipientOriginTypeClass
NotificationRecipientType = NotificationRecipientTypeClass
NotificationRequest = NotificationRequestClass
NotificationSink = NotificationSinkClass
NotificationSinkType = NotificationSinkTypeClass

# fmt: on
