# mypy: ignore-errors
# flake8: noqa

# This file is autogenerated by /metadata-ingestion/scripts/avro_codegen.py
# Do not modify manually!

# pylint: skip-file
# fmt: off
# isort: skip_file
from .......schema_classes import EntityChangeEventClass
from .......schema_classes import ParametersClass
from .......schema_classes import RelationshipChangeEventClass
from .......schema_classes import RelationshipChangeOperationClass


EntityChangeEvent = EntityChangeEventClass
Parameters = ParametersClass
RelationshipChangeEvent = RelationshipChangeEventClass
RelationshipChangeOperation = RelationshipChangeOperationClass

# fmt: on
